/*
 * LimeSurvey
 * Copyright (C) 2007 The LimeSurvey Project Team / Carsten Schmitz
 * All rights reserved.
 * License: GNU/GPL License v2 or later, see LICENSE.php
 * LimeSurvey is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 *
 *
 * Description: Javascript file for templates. Put JS-functions for your template here.
 *
 *
 * $Id:$
 */


/*
 * The function focusFirst puts the Focus on the first non-hidden element in the Survey.
 *
 * Normally this is the first input field (the first answer).
 */
function focusFirst(Event)
{

    $('#limesurvey :input:visible:enabled:first').focus();

}
/*
 * The focusFirst function is added to the eventlistener, when the page is loaded.
 *
 * This can be used to start other functions on pageload as well. Just put it inside the 'ready' function block
 */

/* Uncomment below if you want to use the focusFirst function */
/*
$(document).ready(function(){
    focusFirst();
});
*/


/**
 * Remake table @that with divs, by column
 * Used by array-by-column question type on
 * small screen
 *
 * TODO: remove all the HTML from this function.
 *
 * @param {object} that The table jQuery object
 * @return void
 */
function replaceColumnWithDiv(that) {
    var newHtml = '';
    var nrOfColumns = $(that).find('tr:first th').length;
    newHtml += "<div class='array-by-columns-div'>";
    for (var i = 0; i < nrOfColumns; i++)
    {
        // Fetch each column from the table and put content in div
        newHtml += "<div class='well radio-list array" + (i % 2 === 0 ? "2" : "1") + " '>";
        $(that).find('tr > *:nth-child('+ (i + 2) + ')').each(function(j) {
            // First one is header
            if (j === 0) {
                newHtml += "<div class='answertext clearfix'>";
                newHtml += $(this).html();
                newHtml += "</div>";
            }
            else {                
                newHtml += "<div class='radio-item radio clearfix'>";
                newHtml += $(this).html();
                newHtml += "</div>";
            }
        });
        newHtml += "</div>";
    }
    newHtml += "</div>";
    newHtml = $(newHtml);
    newHtml.find('span.visible-sm-block').each(function(){
        console.log(this);
        $(this).removeClass('visible-xs-block').removeClass('visible-sm-block');
    })
    $(that).replaceWith(newHtml);
}




$(document).ready(function()
{

    // Scroll to first error
    if($(".input-error").length > 0) {
        $('#bootstrap-alert-box-modal').on('hidden.bs.modal', function () {
            console.log('answer error found');
            $firstError = $(".input-error").first();
            $pixToScroll = ( $firstError.offset().top - 100 );
            $('html, body').animate({
                 scrollTop: $pixToScroll + 'px'
             }, 'fast');
        });
    }


    // Make the label clickable
    $('.label-clickable').each(function(){
        var $that    = $(this);
        var attrId = $that.attr('id');
        if(attrId!=undefined){
            attrId = attrId.replace("label-", "");
        } else {
            attrId = "";
        }
        var $inputEl = $("#"+attrId);
        $that.on('click', function(){
            console.log($inputEl.attr('id'));
            $inputEl.trigger( "click" );
        });
    });

    $('.if-no-js').hide();

    // iPad has width 768, Google Nexus 10 width 800
    // It's OK to keep tables on pads.
    if($(window).width() < 768 && 1===2)
    {
        // Brutally remake the array-by-columns question type to divs,
        // because you can't wrap table columns
        $('.array-by-columns-table').each(function() {
            replaceColumnWithDiv(this);
        });

    }

    //var outerframeDistanceFromTop = 50;
    //topsurveymenubar
    var topsurveymenubarHeight = $('#topsurveymenubar').innerHeight();
    var outerframeDistanceFromTop = topsurveymenubarHeight;
    // Manage top container
    if(!$.trim($('#topContainer .container').html()))
    {
        $('#topContainer').hide();
    }
    else
    {
        $('#topContainer').css({
            top: topsurveymenubarHeight+'px',
        });

        $topContainerHeight = $('#topContainer').height();
        outerframeDistanceFromTop += $topContainerHeight;
    }

    if(!$.trim($('#surveynametitle').html()))
    {
        if(!$.trim($('#surveydescription').html()))
        {
            $('#survey-header').hide();
        }
    }

    $('#outerframeContainer').css({marginTop:outerframeDistanceFromTop+'px'});

    $('.language-changer').each(function(){
        $that = $(this);
        if(!$.trim($that.children('div').html()))
        {
            $that.hide();
        }
    });

    $('.group-description-container').each(function(){
        $that = $(this);
        if(!$.trim($that.children('div').html()))
        {
            $that.hide();
        }
    });

    // Hide question help container if empty
    $('.questionhelp').each(function(){
        $that = $(this);
        if(!$.trim($that.html()))
        {
            $that.hide();
        }
    });


    // Load survey button
    if ($('#loadallbtnlink').length > 0){
        $('#loadallbtnlink').on('click', function()
        {
            $('#loadallbtn').trigger('click');
        });
    }

    // Save survey button
    if ($('#saveallbtnlink').length > 0){
        $('#saveallbtnlink').on('click', function()
        {
            $('#saveallbtn').trigger('click');
        });
    }

    // clearall
    if ($('#clearallbtnlink').length > 0){
        $('#clearallbtnlink').on('click', function()
        {
            $('#clearall').trigger('click');
        });
    }

    // Question index
    if($('.linkToButton').length > 0){
        $('.linkToButton').on('click', function()
        {
            $btnToClick = $($(this).attr('data-button-to-click'));
            $btnToClick.trigger('click');
            return false;
        });
    }


    // Errors
    if($('.emtip').length>0)
    {
        // On Document Load
        $('.emtip').each(function(){
            if($(this).hasClass('error'))
            {
                $(this).parents('div.questionhelp').removeClass('text-info').addClass('text-danger');
            }
        });

        // On em change
        $('.emtip').each(function(){
            $(this).on('classChangeError', function() {
                $parent = $(this).parent('div.questionhelp');
                $parent.removeClass('text-info',1);
                $parent.addClass('text-danger',1);

                if ($parent.hasClass('hide-tip'))
                {
                    $parent.removeClass('hide-tip',1);
                    $parent.addClass('tip-was-hidden',1);
                }

                $questionContainer = $(this).parents('div.question-container');
                $questionContainer.addClass('input-error');
            });

            $(this).on('classChangeGood', function() {
                $parent = $(this).parents('div.questionhelp');
                $parent.removeClass('text-danger');
                $parent.addClass('text-info');
                if ($parent.hasClass('tip-was-hidden'))
                {
                    $parent.removeClass('tip-was-hidden').addClass('hide-tip');
                }
                $questionContainer = $(this).parents('div.question-container');
                $questionContainer.removeClass('input-error');
            });
        });
    }

    // Hide the menu buttons at the end of the Survey
    if($(".hidemenubutton").length>0)
    {
        $('.navbar-right').hide();
    }

    // Survey list footer
    if($('#surveyListFooter').length>0)
    {
        $surveyListFooter = $('#surveyListFooter');
        $('#outerframeContainer').after($surveyListFooter);
    }

    $(function () {
        $('[data-toggle="tooltip"]').tooltip()
    })


});


window.alert = function(message, title) {
    if($("#bootstrap-alert-box-modal").length == 0) {
        $("body").append('<div id="bootstrap-alert-box-modal" class="modal fade">\
            <div class="modal-dialog">\
                <div class="modal-content">\
                    <div class="modal-header" style="min-height:40px;">\
                        <button type="button" class="close" data-dismiss="modal" aria-hidden="true">×</button>\
                        <h4 class="modal-title"></h4>\
                    </div>\
                    <div class="modal-body"><p></p></div>\
                    <div class="modal-footer">\
                        <a href="#" data-dismiss="modal" class="btn btn-default">Close</a>\
                    </div>\
                </div>\
            </div>\
        </div>');
    }
    $("#bootstrap-alert-box-modal .modal-header h4").text(title || "");
    $("#bootstrap-alert-box-modal .modal-body p").text(message || "");

    $(document).ready(function()
    {
        $("#bootstrap-alert-box-modal").modal('show');
    });
};


/********************************************************************/
/********************************************************************/

// A plugin to insert an IAT interface
function implicitAssociation(el, showAnswers) {
        
    $(el).each(function() {
			
		var thisQuestion = $(this);
		var thisQuestionHelp = $('div.question-help', thisQuestion);
		var thisQuestionAnswers = $('table.subquestion-list', thisQuestion).parent();
		var startTime = '';
		var endTime = '';	
		var agent = navigator.userAgent.toLowerCase();
		var mobile = false;
		if( /android|webos|iphone|ipad|ipod|blackberry/i.test(navigator.userAgent) ) { // Mobile devices
			mobile = true;
		}
		
		// Some classes
		$(thisQuestion).addClass('iat-question');
		$('tr.subquestion-list', thisQuestion).addClass('unanswered');
		
		// Hide the question help element
		$(thisQuestionHelp).hide();
		$(thisQuestionHelp).closest('.question-help-container').hide();
		
		// Hide the answers
		if(showAnswers != true) {
			$('table.subquestion-list', thisQuestion).hide();
		}
		
		// Insert IAT display
		var iatTexts = $(thisQuestionHelp).text().split('||');
		var iatDisplayHTML = '<div class="iatWrapper">\
								<div class="iatLeftLabel">'+iatTexts[0]+'</div>\
								<div class="iatRightLabel">'+iatTexts[1]+'</div>\
								<div class="iatWord"></div>\
								<div class="iatInstructions">'+iatTexts[2]+'</div>\
							</div>\
							<div class="iatMobileButtonWrapper">\
								<div class="iatButton iatLeftButton">E</div>\
								<div class="iatButton iatRightButton">I</div>\
								<div style="width:100%; clear:both;"></div>\
							</div>';
		$(thisQuestionAnswers).prepend(iatDisplayHTML);
		
		// Show a word
		function iatShowWord() {
			$('div.iatWord', thisQuestion).text($('tr.subquestion-list.unanswered:first .answertext', thisQuestion).text());
			startTime = new Date();
            $('div.iatWord', thisQuestion).html($('tr.subquestion-list.unanswered:first .answertext', thisQuestion).html());
			
			$(document).bind('keypress.iatKeypress', function(e) {
				if(e.which == 101 || e.which == 105) {
					var thisRow = $('tr.subquestion-list.unanswered:eq(0)', thisQuestion);
					$(thisRow).removeClass('unanswered');
					endTime = new Date();
					$('input[type="text"]:eq(1)', thisRow).val(endTime.valueOf() - startTime.valueOf());
					if(e.which == 101) {
						$('input[type="text"]:eq(0)', thisRow).val('E');
					}
					else {
						$('input[type="text"]:eq(0)', thisRow).val('I');
					}
					$(document).unbind('keypress.iatKeypress');
					if($('tr.subquestion-list.unanswered', thisQuestion).length > 0) {
						iatShowWord();
					}
					else {
						$('.iatLeftLabel, .iatWord, .iatRightLabel, .iatInstructions', thisQuestion).fadeOut('slow', function() {
							$('div.iatWord', thisQuestion).text(iatTexts[3]);
							$('.iatWord', thisQuestion).addClass('done').fadeIn('slow');
						});
					}
				}
			});
		}
		function iatShowWordMobile() {
			$('div.iatWord', thisQuestion).text($('tr.subquestion-list.unanswered:first .answertext', thisQuestion).text());
			startTime = new Date();
			$('div.iatWord', thisQuestion).html($('tr.subquestion-list.unanswered:first .answertext', thisQuestion).html());
			$('.iatButton', thisQuestion).bind('click.iatButtonClick', function(e) {
				var thisRow = $('tr.subquestion-list.unanswered:eq(0)', thisQuestion);
				$(thisRow).removeClass('unanswered');
				endTime = new Date();
				$('input[type="text"]:eq(1)', thisRow).val(endTime.valueOf() - startTime.valueOf());
				$('input[type="text"]:eq(0)', thisRow).val($(this).text());
				$('.iatButton', thisQuestion).unbind('click.iatButtonClick');
				if($('tr.subquestion-list.unanswered', thisQuestion).length > 0) {
					iatShowWordMobile();
				}
				else {
					$('.iatLeftLabel, .iatWord, .iatRightLabel, .iatInstructions, .iatMobileButtonWrapper', thisQuestion).fadeOut('slow', function() {
						$('div.iatWord', thisQuestion).text(iatTexts[3]);
						$('.iatWord', thisQuestion).addClass('done').fadeIn('slow');
					});
				}
			});
		}
		
		// Start the IAT display
		if(mobile == true) { // Mobile devices
			$('.iatMobileButtonWrapper', thisQuestion).show();
			$('.iatButton', thisQuestion).bind('click.iatStartMobile', function(e) {
				$('.iatButton', thisQuestion).unbind('click.iatStartMobile');
				iatShowWordMobile();
			});
		}
		else {
			$(document).bind('keypress.iatStart', function(e) { // Non-mobile devices
				if(e.which == 101 || e.which == 105) {
					$(document).unbind('keypress.iatStart');
					iatShowWord();
				}
			});
		}
	});
}

/********************************************************************/
/********************************************************************/

function maxDiff(qID, randomize) {
 
    // Identify some elements
	var thisQuestion = $('#question'+qID);
	var thisTable = $('table.subquestion-list:eq(0)', thisQuestion);
 
	// Assign a new question class
	$(thisQuestion).addClass('max-diff-array');
 
	// Move the columns
	$('thead tr:eq(0) th:eq(1)', thisTable).prependTo('thead tr:eq(0)', thisTable);
	$('tr.answers-list', thisTable).each(function(i){
		$('td.answer-item:eq(0)', this).prependTo(this);
	});
 
	// Random rows
	if(randomize) {
		var rowsArr = [];
		$('tr.answers-list', thisTable).each(function(i){
			$(this).attr('data-index', i);
			rowsArr.push(i);
		});
		shuffleArray(rowsArr);
		$(rowsArr).each(function(i){
			$('tbody', thisTable).append($('tr[data-index="'+this+'"]', thisTable));
		});
	}
 
	// Prevent clicking twice in the same row
	$('input.radio', thisQuestion).on('click', function () {
 
		$('input.radio', thisQuestion).prop('disabled', false);
		$('input.radio:checked', thisQuestion).each(function(i) {
			var thisRow = $(this).closest('tr.answers-list');
			$('input.radio', thisRow).not(this).prop('disabled', true);
		});
	});	
 
	// Fix up the row classes
	var rowClass = 1;
	$('tr.answers-list', thisTable).each(function(i) {
		$(this).addClass('array'+(2-(i%2)));
	});
}
 
function shuffleArray(array) {
	for (var i = array.length - 1; i > 0; i--) {
		var j = Math.floor(Math.random() * (i + 1));
		var temp = array[i];
		array[i] = array[j];
		array[j] = temp;
	}
	return array;
}
/********************************************************************/
/********************************************************************/
$(document).ready(function() {
    
	$('.spaceGrid').each(function(i){

		// Define some vars
		var thisQuestion = $(this).closest('.numeric-multi');
		var thisTable = $(this).closest('table.spaceGrid');
		var numGridCell = $('.gridCell', thisTable).length;
		var numCols = $('tr:eq(0) .gridCell', thisTable).length;
		var numRows = numGridCell/numCols;
		
		
		// Initial state
		var xCoord = $('input.text:eq(0)', thisQuestion).val() - 1;
		var yCoord = numRows - $('input.text:eq(1)', thisQuestion).val();
		$('tr:eq('+yCoord+') .gridCell:eq('+xCoord+')', thisTable).addClass('checkedCell');
	
		// Listener on the grid cells
		$('.gridCell').click(function(){
			var thisRow = $(this).closest('tr');
	
			// Add class to checked cell
			$('.checkedCell', thisQuestion).removeClass('checkedCell');
			$(this).addClass('checkedCell');
	
			// Find the cell coordinates
			var reverseRowIndex = (numRows - $('tr', thisTable).index($(thisRow)));
			var colIndex = $('.gridCell', thisRow).index($(this)) + 1;
	
			// Load coordinates into inputs
			$('input.text:eq(0)', thisQuestion).val(colIndex);
			$('input.text:eq(1)', thisQuestion).val(reverseRowIndex);
		});
	});

});
 $(document).ready(function(){
    // Apply the responsiveArray plugin with default settings
    $('.array-10-pt, .array-flexible-row, .array-5-pt, .array-increase-same-decrease, .array-yes-uncertain-no').responsiveArray();
});
 
/***** 
    A plugin to insert drop-downs into arrays for small screens
    Copyright (C) 2015 - Tony Partner (http://partnersurveys.com)
    Licensed MIT, GPL
    Version - 2.0
    Create date - 09/04/15
*****/
(function( $ ){
    $.fn.responsiveArray = function(options) {
    
        var opts = $.extend( {
            chooseText: 'Select one...'            
        }, options);
 
        return this.each(function() {
 
            var thisQuestion = $(this);
            var thisQID = $(thisQuestion).attr('id').split('question')[1];

            // Some classes
            $(thisQuestion).addClass('responsive-array');
            $('table.questions-list tr', thisQuestion).each(function(i){
                $('> *', this).each(function(i){
                    $(this).addClass('col-'+i);
                    if(i != 0) {
                        $(this).addClass('expanded');
                    }
                });
            });

            // Insert a column
            $('.col-0', thisQuestion).after('<td class="dropdown-cell" />');

            // Insert dropdowns
            $('body').append('<select style="display:none;" class="responsive-select responsive-select-'+thisQID+'" />');
            $('table.questions-list thead th.expanded', thisQuestion).each(function(i){
                $('.responsive-select-'+thisQID).append('<option value="">'+$(this).text()+'</option>');
            });
            $('table.questions-list tbody .dropdown-cell', thisQuestion).append($('.responsive-select-'+thisQID+'').clone());
            $('tr.radio-list', thisQuestion).each(function(i){
                var thisRow = $(this);
                $('input.radio', this).each(function(i){
                    $('.responsive-select-'+thisQID+' option:eq('+i+')', thisRow).attr('value', $(this).attr('id'));
                });                    
                if($('input.radio:checked', thisRow).length > 0) {
                    $('.responsive-select-'+thisQID+'', thisRow).val($('input.radio:checked', thisRow).attr('id'));
                }
                else {
                    $('.responsive-select-'+thisQID+'', thisRow).prepend('<option value="" selected="selected">'+opts.chooseText+'</option>');
                }
            });
            $('.responsive-select-'+thisQID+'', thisQuestion).show();

            // Listeners on radios
            $('input.radio', thisQuestion).click(function(event) {
                var thisRow = $(this).closest('tr');
                var thisID = $(this).attr('id');
                //$('option[value="'+thisID+'"]').attr('selected', 'selected');
                $('.responsive-select', thisRow).val(thisID);
                $('.responsive-select option[value=""]', thisRow).remove();
            });

            // Listeners on dropdowns
            $('.responsive-select-'+thisQID+'').change(function() {
                $('#'+$(this).val()+'').click();
            });
 
        });
    };
})( jQuery );
// A function to handle "secondary" checkboxes
function secondaryCheckboxes(qID, primaryPosition, secondaryCount) {
    // Identify the elements
	var thisQuestion = $('#question'+qID);
	$('div.question-item', thisQuestion).parent().addClass('answer-row');
	var primaryRow = $('div.question-item:eq('+(primaryPosition-1)+')', thisQuestion).closest('.answer-row');
	var primaryInput = $('input.checkbox', primaryRow);
	var secondaryRows = primaryRow.nextAll('div.answer-row:lt('+(secondaryCount)+')');
	var secondaryInputs = $('input.checkbox', secondaryRows);
	
	// Indent the secondaries
	secondaryRows.css({ 'margin-left':'2.5em' });
	
	// Initial states of the secondary answers
	if (primaryInput.prop('checked') == false ) {
		secondaryRows.hide(); 
	} 
	
	// A listener on the primary answer to show or hide secondary answers 
	primaryInput.click(function (event) { 
		
		// Hide/show the secondary answers accordingly
		if (!$(this).is(':checked')) {
			secondaryRows.hide();				
			secondaryInputs.prop('checked', false);
			secondaryInputs.each(function(i) {
				checkconditions(this.value, this.name, this.type);
			});
		}
		else {
			secondaryRows.show(); 
		}
	});
}